@@ -1,8 +1,6 @@
 package Graphics::Primitive::Component;
 use Moose;
 
-with 'Layout::Manager::Component';
-
 use Graphics::Primitive::Border;
 use Graphics::Primitive::Insets;
 use Geometry::Primitive::Point;
@@ -15,23 +13,34 @@ has 'border' => (
     default => sub { Graphics::Primitive::Border->new() }
 );
 has 'color' => ( is => 'rw', isa => 'Graphics::Color');
+has 'height' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
 has 'margins' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Insets',
     default => sub { Graphics::Primitive::Insets->new() }
 );
-has '+origin' => ( default => sub { Geometry::Primitive::Point->new() } );
+has 'name' => ( is => 'rw', isa => 'Str' );
+has 'origin' => (
+    is => 'rw',
+    isa => 'Geometry::Primitive::Point',
+    default =>  sub { Geometry::Primitive::Point->new( x => 0, y => 0 ) },
+);
 has 'padding' => (
     is => 'rw',
     isa => 'Graphics::Primitive::Insets',
     default => sub { Graphics::Primitive::Insets->new() }
 );
+has 'maximum_height' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
+has 'maximum_width' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
+has 'minimum_height' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
+has 'minimum_width' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
+has 'preferred_height' => ( is => 'rw', isa => 'Num', default => sub { 0 });
+has 'preferred_width' => ( is => 'rw', isa => 'Num', default => sub { 0 });
 has 'visible' => ( is => 'rw', isa => 'Bool', default => sub { 1 } );
+has 'width' => ( is => 'rw', isa => 'Num', default => sub { 0 } );
 
 sub prepare { }
 
-sub draw { }
-
 sub inside_width {
     my $self = shift();
 
@@ -62,10 +71,10 @@ sub inside_bounding_box {
 
     my $rect = Geometry::Primitive::Rectangle->new(
         origin => Geometry::Primitive::Point->new(
-            x => $self->origin->x + $self->padding->left
-                + $self->border->width + $self->margins->left,
-            y => $self->origin->y + $self->padding->top
-                + $self->border->width + $self->margins->top
+            x => $self->padding->left + $self->border->width
+                + $self->margins->left,
+            y => $self->padding->top + $self->border->width
+                + $self->margins->top
         ),
         width => $self->inside_width,
         height => $self->inside_height
@@ -98,8 +107,7 @@ Graphics::Primitive::Component
 
 =head1 DESCRIPTION
 
-A Component is an entity with a graphical representation.  This class
-implements L<Layout::Manager::Component> for use with a layout manager.
+A Component is an entity with a graphical representation.
 
 =head1 SYNOPSIS
 
@@ -139,15 +147,15 @@ L<Border|Graphics::Primitive::Border>.
 
 Set this component's foreground color.
 
-=item I<draw>
+=item I<height>
 
-Method to actually draw this component.  This is an empty sub and is meant to
-be overriden by a specific implemntation.
+Set this component's height.
 
 =item I<inside_bounding_box>
 
 Returns a L<Rectangle|Geometry::Primitive::Rectangle> that defines the edges
-of the 'inside' box for this component.
+of the 'inside' box for this component.  This box is relative to the origin
+of the component.
 
 =item I<inside_height>
 
@@ -171,6 +179,10 @@ border.
 Set this component's name.  This is not required, but may inform consumers
 of a component.  Pay attention to that library's documentation.
 
+=item I<origin>
+
+Set/Get the origin point for this component.
+
 =item I<outside_height>
 
 Get the height consumed by padding, margin and borders.
@@ -191,6 +203,38 @@ border and the component's content.
 Method to prepare this component for drawing.  This is an empty sub and is
 meant to be overriden by a specific implemntation.
 
+=item I<maximum_height>
+
+Set/Get this component's maximum height.  Used to inform a layout manager.
+
+item I<maximum_width>
+
+Set/Get this component's maximum width.  Used to inform a layout manager.
+
+item I<minimum_height>
+
+Set/Get this component's minimum height.  Used to inform a layout manager.
+
+item I<minimum_width>
+
+Set/Get this component's minimum width.  Used to inform a layout manager.
+
+=item I<preferred_height>
+
+Set/Get this component's preferred height.  Used to inform a layout manager.
+
+=item I<preferred_width>
+
+Set/Get this component's preferred width.  Used to inform a layout manager.
+
+=item I<visible>
+
+Set/Get this component's visible flag.
+
+=item I<width>
+
+Set/Get this component's width.
+
 =back
 
 =head1 AUTHOR
